Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(290)

Unified Diff: headless/test/headless_browser_test.h

Issue 2873283002: [Reland] Allow headless TabSocket in isolated worlds & remove obsolete logic (Closed)
Patch Set: Fix GN Issue Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « headless/public/headless_web_contents.h ('k') | headless/test/headless_browser_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: headless/test/headless_browser_test.h
diff --git a/headless/test/headless_browser_test.h b/headless/test/headless_browser_test.h
index e5e29e5f214f3d2c9bf43455efed183a4528d2e8..1e3bc1674432f8901a10e7958ae4f3a42e5ffa3a 100644
--- a/headless/test/headless_browser_test.h
+++ b/headless/test/headless_browser_test.h
@@ -120,8 +120,12 @@ class HeadlessAsyncDevTooledBrowserTest : public HeadlessBrowserTest,
// the map returned is empty.
virtual ProtocolHandlerMap GetProtocolHandlers();
- // Whether or not we should request a TabSocket when creating |web_contents_|.
- virtual bool GetCreateTabSocket();
+ // The TabSocket type to request when creating |web_contents_|.
+ virtual HeadlessWebContents::Builder::TabSocketType GetTabSocketType();
+
+ // Selects between creating the TabSocket only in an isolated world or the
+ // main world.
+ virtual bool GetCreateTabSocketOnlyForIsolatedWorld();
protected:
void RunTest();
« no previous file with comments | « headless/public/headless_web_contents.h ('k') | headless/test/headless_browser_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698